utils::globalVariables(c(
  "all_of",
  ".data",
  ":=",
  "Count",
  "co_occurrence",
  "colours",
  "doc_id",
  "freq",
  "is_concept",
  "keyword",
  "lemma",
  "median",
  "n",
  "name",
  "ngram",
  "occurrence",
  "pagerank",
  "par",
  "Proportion",
  "quantile",
  "reorder",
  "sentence",
  "token",
  "unique_word",
  "upos",
  "UPOS",
  "UPOS_Name",
  "weight",
  "word_type",
  "word1",
  "word2",
  "words"
))
